% msuphysletter.cls
% INTRODUCTION

% VERSION HISTORY
% Written:  99.04.20 - M A Weber. Based (heavily!) upon _A_Guide_to_ 
%                                 _LaTeX_, Kopka & Daly, 1999 (3rd 
%                                 ed), and upon _The_LaTeX_Companion_,
%                                 Goossens, Mittelbach, and Samarin, 
%                                 1994.
% Modified: 99.04.26 - M A Weber.   Added "Ref.:" field to opening.
%           99.06.01 - P Martens    Raised header. Reduced header 
%                      & M A Weber. block spacing and fixed "Email"
%                                   bug. Adjusted some other spacings.


% This class file msuphysletter.cls was written to produce letters 
% with the MSU Physics letterhead. It is not meant to be editted 
% if the template msuphys_template.tex is used as intended. See the 
% remarks in the template file and the README for some instructions 
% on use.


% ------------------------Identification part------------------------

% Specify the TeX format and identify the new class file.
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{msuphysletter}


% --------------------------Package loading--------------------------

% Necessary to be able to execute conditionals and import MSU logo.
\RequirePackage{ifthen}
\RequirePackage{graphics}


% ----------------------Declaration of options-----------------------

% All options valid in the <letter> class will be accepted here, so
% pass them on to that class. Then process all options before loading
% <letter>.
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{letter}}


% -----------------------Execution of options------------------------

\ProcessOptions


% --------------------Special class file commands--------------------

\LoadClass{letter}


% -----------------------------Main code-----------------------------

% Create some internal commands (with "@" in name) which store the 
% text arguments retrieved from the <.tex> file with the "non-@" 
% commands.
\newcommand{\msu@fax}{}
\newcommand{\msu@email}{}
\newcommand{\msu@url}{}
\newcommand{\msu@ref}{}

\newcommand{\msufax}[1]{\renewcommand{\msu@fax}{#1}}
\newcommand{\msuemail}[1]{\renewcommand{\msu@email}{#1}}
\newcommand{\msuurl}[1]{\renewcommand{\msu@url}{#1}}
\newcommand{\msuref}[1]{\renewcommand{\msu@ref}{#1}}

% Use fixed fonts in letterhead, specified by NFSS attributes.
% (Computer Modern Roman)
\DeclareFixedFont{\viiirm}{OT1}{cmr}{m}{n}{8}
\DeclareFixedFont{\xrm}{OT1}{cmr}{m}{n}{10}
\DeclareFixedFont{\xiirm}{OT1}{cmr}{m}{n}{12}

% Divide letterhead and opening into left- and rightside fields.
\newlength{\leftfield}  \setlength{\leftfield}{110mm}
\newlength{\rightfield} \setlength{\rightfield}{55mm}

\setlength{\textwidth}{165mm}
\setlength{\oddsidemargin}{0mm}
\setlength{\topmargin}{-52mm}
\setlength{\textheight}{180mm}

% Import the PostScript file of the MSU logo and save it as a unit.
\newsavebox{\msulogo}
\savebox{\msulogo}[\leftfield][t]{%
  \resizebox{35mm}{!}{\includegraphics{msu_logo.eps}}\hfill}

% In the <letter> class, there is a special page style for the first
% page. We want to redefine it to use our new header.
\renewcommand{\ps@firstpage}
  { \setlength{\headheight}{45mm} \setlength{\headsep}{40mm}%
    \setlength{\topskip}{30mm}%
    \renewcommand{\@oddhead}{\raisebox{-25mm}{\usebox{\msulogo}} %
        \parbox[t]{\rightfield}{ {\xrm\bf Department of Physics\\[3mm]}
            \viiirm\setlength{\baselineskip}{3.5mm}
            College of Letters and Science\\
            Montana State University - Bozeman\\
            P.O.Box 173840\\
            Bozeman, MT 59717-3840\\[2.5mm]
            \ifthenelse{\equal{\fromname}{}}{}{\fromname\\}
            \makebox[0.6in][l]{Telephone}
               \ifthenelse{\equal{\telephonenum}{}}
                           {406-994-3614\\}{\telephonenum\\}
            \makebox[0.6in][l]{FAX}
               \ifthenelse{\equal{\msu@fax}{}}{406-994-4452\\}{\msu@fax\\}
            \ifthenelse{\equal{\msu@email}{}}{}{\makebox[0.6in][l]{Email} 
               \msu@email\\}
            \ifthenelse{\equal{\msu@url}{}}{}{\msu@url} }}
    \renewcommand{\@oddfoot}{}
    \renewcommand{\@evenhead}{} \renewcommand{\@evenfoot}{}}

% And now we redefine the header for the succeeding pages.
\renewcommand{\ps@headings}
  { \setlength{\headheight}{40mm}%
    \renewcommand{\@oddhead}
      {\parbox{\textwidth}{\headtoname{} \toname\hfill\@date\hfill
                           \pagename{} \thepage\\
                           \rule[3pt]{\textwidth}{1pt}}}
    \renewcommand{\@oddfoot}{}
    \renewcommand{\@evenhead}{\@oddhead}
    \renewcommand{\@evenfoot}{\@oddfoot} }

% According to the Guide, the head and foot commands may not exist yet
% the first time these page styles are executed, which would cause
% \renewcommand to complain. These next lines avoid this by 
% predefining those commands at the start.
\providecommand{\oddhead}{}
\providecommand{\oddfoot}{}
\providecommand{\evenhead}{}
\providecommand{\evenfoot}{}

% Make <headings> the active page style.
\pagestyle{headings}

% Now we redefine the opening to include some personalized info with
% the header. For some reason, the "variable" commands (eg, \fromname)
% don't work in the header savebox, so we include the sender's info
% in the opening and shift it right up under the rest of the header
% info. The recipient's info is pretty close to the <letter> standard.
\renewcommand{\opening}[1]{\thispagestyle{firstpage}%
  \parbox[t]{\leftfield}{\@date
                         \\[8mm]
                         \toname\\
                         \toaddress
                         \ifthenelse{\equal{\msu@ref}{}}{}%
                           {\\[3ex] Ref: \msu@ref}
                         \\[8mm]
                         #1 \par\nobreak}} 
